@@ -2,9 +2,11 @@
 #undef VERSION
 #undef AT_BINDIR
 #undef GETTEXT_PACKAGE
+#undef GDM_CONFIGDIR
 #undef GDM_USER_PATH
 #undef HALT_COMMAND
 #undef REBOOT_COMMAND
+#undef SOUND_PROGRAM
 #undef SUSPEND_COMMAND
 #undef ENABLE_IPV6
 #undef ENABLE_NLS
