@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,15 +17,14 @@
  */
 
 #include <config.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <syslog.h>
 #include <signal.h>
 #include <sys/wait.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <fcntl.h>
-
-#include <vicious.h>
+#include <errno.h>
 
 #include "gdm.h"
 #include "gdm-net.h"
@@ -37,9 +36,9 @@
 #include "choose.h"
 #include "auth.h"
 #include "gdm-net.h"
+#include "gdmconfig.h"
 
 /* External vars */
-extern gboolean GdmXdmcp;
 extern gint xdmcp_sessions;
 extern gint flexi_servers;
 extern gint xdmcp_pending;
@@ -59,9 +58,6 @@ gdm_display_check_loop (GdmDisplay *disp)
   
   now = time (NULL);
 
-  if (disp->disabled)
-    return FALSE;
-
   gdm_debug ("loop check: last_start %ld, last_loop %ld, now: %ld, retry_count: %d", (long)disp->last_start_time, (long) disp->last_loop_start_time, (long) now, disp->retry_count);
   
   if (disp->last_loop_start_time > now || disp->last_loop_start_time == 0)
@@ -112,13 +108,13 @@ gdm_display_check_loop (GdmDisplay *disp)
 	   * or just wait for the stupid malicious user to get bored
 	   * and go away */
 	  char *s = g_strdup_printf (C_(N_("The display server has been shut down "
-					   "about 6 times in the last 90 seconds, "
-					   "it is likely that something bad is "
-					   "going on.  I will wait for 2 minutes "
+					   "about 6 times in the last 90 seconds. "
+					   "It is likely that something bad is "
+					   "going on.  Waiting for 2 minutes "
 					   "before trying again on display %s.")),
 					disp->name);
 	  /* only display a dialog box if this is a local display */
-	  if (disp->type == TYPE_LOCAL ||
+	  if (disp->type == TYPE_STATIC ||
 	      disp->type == TYPE_FLEXI) {
 		  gdm_text_message_dialog (s);
 	  }
@@ -170,7 +166,7 @@ whack_old_slave (GdmDisplay *d, gboolean kill_connection)
     gboolean waitsleep = TRUE;
 
     if (kill_connection) {
-	    /* This should never happen I don't think, but just in case */
+	    /* This should never happen, but just in case */
 	    if (d->socket_conn != NULL) {
 		    GdmConnection *conn = d->socket_conn;
 		    d->socket_conn = NULL;
@@ -204,13 +200,11 @@ wait_again:
 		    /* rekill the slave to tell it to
 		       hurry up and die if we're getting
 		       killed ourselves */
-		    if (ve_signal_was_notified (SIGTERM) ||
-			ve_signal_was_notified (SIGINT) ||
-			ve_signal_was_notified (SIGHUP) ||
-			t + 10 <= time (NULL)) {
-			    gdm_debug ("whack_old_slave: GOT ANOTHER SIGTERM (or it was 10 secs already), killing slave again");
+		    if ((gdm_signal_terminthup_was_notified ()) ||
+			(t + 10 <= time (NULL))) {
+			    gdm_debug ("whack_old_slave: GOT ANOTHER SIGTERM (or it was 10 secs already), killing slave again with SIGKILL");
 			    t = time (NULL);
-			    kill (d->slavepid, SIGTERM);
+			    kill (d->slavepid, SIGKILL);
 			    goto wait_again;
 		    } else if (ret < 0 && errno == EINTR) {
 			    goto wait_again;
@@ -297,7 +291,7 @@ gdm_display_manage (GdmDisplay *d)
 	d->slavepid = getpid ();
 
 	/* Close XDMCP fd in slave process */
-	if (GdmXdmcp)
+	if (gdm_get_value_bool (GDM_KEY_XDMCP))
 	    gdm_xdmcp_close ();
 
 	gdm_connection_close (fifoconn);
@@ -333,7 +327,7 @@ gdm_display_manage (GdmDisplay *d)
 
     case -1:
 	d->slavepid = 0;
-	gdm_error (_("%s: Failed forking gdm slave process for %s"),
+	gdm_error (_("%s: Failed forking GDM slave process for %s"),
 		   "gdm_display_manage",
 		   d->name);
 
@@ -392,7 +386,7 @@ gdm_display_unmanage (GdmDisplay *d)
     whack_old_slave (d, TRUE /* kill_connection */);
     
     d->dispstat = DISPLAY_DEAD;
-    if (d->type != TYPE_LOCAL)
+    if (d->type != TYPE_STATIC)
 	gdm_display_dispose (d);
 
     gdm_debug ("gdm_display_unmanage: Display stopped");
@@ -412,12 +406,13 @@ count_session_limits (void)
 
 	for (li = displays; li != NULL; li = li->next) {
 		GdmDisplay *d = li->data;
-		if (d->type == TYPE_XDMCP) {
+		if (SERVER_IS_XDMCP (d)) {
 			if (d->dispstat == XDMCP_MANAGED)
 				xdmcp_sessions ++;
 			else if (d->dispstat == XDMCP_PENDING)
 				xdmcp_pending ++;
-		} else if (SERVER_IS_FLEXI (d)) {
+		}
+		if (SERVER_IS_FLEXI (d)) {
 			flexi_servers ++;
 		}
 	}
@@ -485,11 +480,19 @@ gdm_display_dispose (GdmDisplay *d)
     g_free (d->authfile_gdm);
     d->authfile_gdm = NULL;
 
-    if (d->xnest_temp_auth_file != NULL) {
-	    VE_IGNORE_EINTR (unlink (d->xnest_temp_auth_file));
+    if (d->type == TYPE_XDMCP_PROXY) {
+	    if (d->parent_auth_file != NULL) {
+		    VE_IGNORE_EINTR (unlink (d->parent_auth_file));
+	    }
+	    g_free (d->parent_auth_file);
+	    d->parent_auth_file = NULL;
     }
-    g_free (d->xnest_temp_auth_file);
-    d->xnest_temp_auth_file = NULL;
+
+    if (d->parent_temp_auth_file != NULL) {
+	    VE_IGNORE_EINTR (unlink (d->parent_temp_auth_file));
+    }
+    g_free (d->parent_temp_auth_file);
+    d->parent_temp_auth_file = NULL;
 
     if (d->auths) {
 	    gdm_auth_free_auth_list (d->auths);
@@ -517,11 +520,11 @@ gdm_display_dispose (GdmDisplay *d)
 	    gdm_choose_indirect_dispose_empty_id (d->indirect_id);
     d->indirect_id = 0;
 
-    g_free (d->xnest_disp);
-    d->xnest_disp = NULL;
+    g_free (d->parent_disp);
+    d->parent_disp = NULL;
 
-    g_free (d->xnest_auth_file);
-    d->xnest_auth_file = NULL;
+    g_free (d->parent_auth_file);
+    d->parent_auth_file = NULL;
 
     g_free (d->login);
     d->login = NULL;
