@@ -89,7 +89,7 @@
 #endif
 #endif /* HAVE_LIBXDMCP */
 
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 
 #ifdef HAVE_LIBXDMCP
 #include "gdm.h"
@@ -356,8 +356,8 @@ gdm_xdmcp_init (void)
 	    uname (&name);
 	    sysid = g_strconcat (name.sysname, " ", name.release, NULL);
 
-	    servhost.data = g_strdup (hostbuf);
-	    servhost.length = strlen (servhost.data);
+	    servhost.data = (CARD8 *) g_strdup (hostbuf);
+	    servhost.length = strlen ((char *) servhost.data);
 	    
 	    initted = TRUE;
     }
@@ -414,7 +414,7 @@ gdm_xdmcp_init (void)
 	    ifc.ifc_buf = buf = malloc (ifc.ifc_len);
 	    if (ioctl (socktemp, SIOCGIFCONF, &ifc) >= 0) {
 		ifr = ifc.ifc_req;
-		num = ifc.ifc_len / sizeof(struct ifreq); /* No of interfaces */
+		num = ifc.ifc_len / sizeof (struct ifreq); /* No of interfaces */
 
 		/* Joining multicast group with all interfaces*/
 		for (i = 0 ; i < num ; i++) {
@@ -440,7 +440,7 @@ gdm_xdmcp_init (void)
 
 		    mreq.ipv6mr_interface = ifindex;
 		    inet_pton (AF_INET6, gdm_get_value_string (GDM_KEY_MULTICAST_ADDR), &mreq.ipv6mr_multiaddr);
-		    setsockopt (gdm_xdmcpfd, IPPROTO_IPV6, IPV6_JOIN_GROUP, &mreq, sizeof(mreq));
+		    setsockopt (gdm_xdmcpfd, IPPROTO_IPV6, IPV6_JOIN_GROUP, &mreq, sizeof (mreq));
 		} 
            }
            g_free (buf);
@@ -671,7 +671,7 @@ gdm_xdmcp_handle_query (struct sockaddr_in *clnt_sa, gint len, gint type)
     /* Crude checksumming */
     for (i = 0 ; i < clnt_authlist.length ; i++) {
 	    if G_UNLIKELY (gdm_get_value_bool (GDM_KEY_DEBUG)) {
-		    char *s = g_strndup (clnt_authlist.data[i].data, clnt_authlist.length);
+		    char *s = g_strndup ((char *) clnt_authlist.data[i].data, clnt_authlist.length);
 		    gdm_debug ("gdm_xdmcp_handle_query: authlist: %s", ve_sure_string (s));
 		    g_free (s);
 	    }
@@ -863,7 +863,7 @@ gdm_xdmcp_send_forward_query (GdmIndirectDisplay *id,
 
 	/* we depend on this being 2 elsewhere as well */
 	port.length = 2;
-	port.data = g_new (char, 2);
+	port.data = (CARD8 *) g_new (char, 2);
 	memcpy (port.data, &(clnt_sa->sin_port), 2);
 
 	address.length = sizeof (struct in_addr);
@@ -1120,7 +1120,7 @@ gdm_xdmcp_handle_forward_query (struct sockaddr_in *clnt_sa, gint len)
     
     for (i = 0 ; i < clnt_authlist.length ; i++) {
 	    if G_UNLIKELY (gdm_get_value_bool (GDM_KEY_DEBUG)) {
-		    char *s = g_strndup (clnt_authlist.data[i].data, clnt_authlist.length);
+		    char *s = g_strndup ((char *) clnt_authlist.data[i].data, clnt_authlist.length);
 		    gdm_debug ("gdm_xdmcp_handle_forward_query: authlist: %s", ve_sure_string (s));
 		    g_free (s);
 	    }
@@ -1150,8 +1150,8 @@ gdm_xdmcp_handle_forward_query (struct sockaddr_in *clnt_sa, gint len)
 		memcpy (&((struct sockaddr_in *)(&tmp_disp_sa))->sin_addr.s_addr, clnt_addr.data, 4);
 
 		char * ipv4_addr = inet_ntoa (((struct sockaddr_in *)(&tmp_disp_sa))->sin_addr);
-		strcpy(buffer6, "::ffff:");
-		strncat(buffer6, ipv4_addr, INET_ADDRSTRLEN);
+		strcpy (buffer6, "::ffff:");
+		strncat (buffer6, ipv4_addr, INET_ADDRSTRLEN);
 
 		inet_pton (AF_INET6, buffer6, &ipv6_addr);
 		ipv6_addr_ptr = &ipv6_addr;
@@ -1283,9 +1283,9 @@ gdm_xdmcp_send_willing (struct sockaddr_in *clnt_sa)
 	    gdm_xdmcp_displays_from_host (clnt_sa) >= dispperhost) {
 		/* Don't translate, this goes over the wire to servers where we
 		 * don't know the charset or language, so it must be ascii */
-		status.data = g_strdup_printf ("%s (Server is busy)", last_status);
+		status.data = (CARD8 *) g_strdup_printf ("%s (Server is busy)", last_status);
 	} else {
-		status.data = g_strdup (last_status);
+		status.data = (CARD8 *) g_strdup (last_status);
 	}
      }
     else
@@ -1295,13 +1295,13 @@ gdm_xdmcp_send_willing (struct sockaddr_in *clnt_sa)
 	    gdm_xdmcp_displays_from_host (clnt_sa) >= dispperhost) {
 		/* Don't translate, this goes over the wire to servers where we
 		 * don't know the charset or language, so it must be ascii */
-		status.data = g_strdup_printf ("%s (Server is busy)", last_status);
+		status.data = (CARD8 *) g_strdup_printf ("%s (Server is busy)", last_status);
 	} else {
-		status.data = g_strdup (last_status);
+		status.data = (CARD8 *) g_strdup (last_status);
 	}
     }
 
-    status.length = strlen (status.data);
+    status.length = strlen ((char *) status.data);
     
     header.opcode = (CARD16) WILLING;
     header.length = 6 + serv_authlist.authentication.length;
@@ -1358,8 +1358,8 @@ gdm_xdmcp_send_unwilling (struct sockaddr_in *clnt_sa, gint type)
     
     /* Don't translate, this goes over the wire to servers where we
      * don't know the charset or language, so it must be ascii */
-    status.data = "Display not authorized to connect";
-    status.length = strlen (status.data);
+    status.data = (CARD8 *) "Display not authorized to connect";
+    status.length = strlen ((char *) status.data);
     
     header.opcode = (CARD16) UNWILLING;
     header.length = 4 + servhost.length + status.length;
@@ -1597,7 +1597,7 @@ gdm_xdmcp_handle_request (struct sockaddr_in *clnt_sa, gint len)
 	return;
     }
 
-    gdm_xdmcp_displays_check(); /* Purge pending displays */
+    gdm_xdmcp_displays_check (); /* Purge pending displays */
     
     /* Remote display number */
     if G_UNLIKELY (! XdmcpReadCARD16 (&buf, &clnt_dspnum)) {
@@ -1651,10 +1651,10 @@ gdm_xdmcp_handle_request (struct sockaddr_in *clnt_sa, gint len)
 	return;
     }
     
-    /* libXdmcp doesn't terminate strings properly so we cheat and use strncmp() */
+    /* libXdmcp doesn't terminate strings properly so we cheat and use strncmp () */
     for (i = 0 ; i < clnt_authorization.length ; i++)
 	if (clnt_authorization.data[i].length == 18 &&
-	    strncmp (clnt_authorization.data[i].data, "MIT-MAGIC-COOKIE-1", 18) == 0)
+	    strncmp ((char *) clnt_authorization.data[i].data, "MIT-MAGIC-COOKIE-1", 18) == 0)
 	    mitauth = TRUE;
     
     /* Manufacturer ID */
@@ -1707,7 +1707,7 @@ gdm_xdmcp_handle_request (struct sockaddr_in *clnt_sa, gint len)
     }
 
     if G_UNLIKELY (gdm_get_value_bool (GDM_KEY_DEBUG)) {
-	    char *s = g_strndup (clnt_manufacturer.data, clnt_manufacturer.length);
+	    char *s = g_strndup ((char *) clnt_manufacturer.data, clnt_manufacturer.length);
 	    gdm_debug ("gdm_xdmcp_handle_request: xdmcp_pending=%d, MaxPending=%d, xdmcp_sessions=%d, MaxSessions=%d, ManufacturerID=%s",
 		       xdmcp_pending, maxpending, xdmcp_sessions, maxsessions, ve_sure_string (s));
 	    g_free (s);
@@ -1804,10 +1804,10 @@ gdm_xdmcp_send_accept (GdmHostent *he /* eaten and freed */,
     authendata.data = (CARD8 *) 0;
     authendata.length = (CARD16) 0;
     
-    authname.data = "MIT-MAGIC-COOKIE-1";
-    authname.length = strlen (authname.data);
+    authname.data = (CARD8 *) "MIT-MAGIC-COOKIE-1";
+    authname.length = strlen ((char *) authname.data);
     
-    authdata.data = d->bcookie;
+    authdata.data = (CARD8 *) d->bcookie;
     authdata.length = 16;
     
     header.version = XDM_PROTOCOL_VERSION;
@@ -1881,8 +1881,8 @@ gdm_xdmcp_send_decline (struct sockaddr_in *clnt_sa, const char *reason)
     authendata.data = (CARD8 *) 0;
     authendata.length = (CARD16) 0;
     
-    status.data = (char *)reason;
-    status.length = strlen (status.data);
+    status.data = (CARD8 *) reason;
+    status.length = strlen ((char *) status.data);
     
     header.version = XDM_PROTOCOL_VERSION;
     header.opcode = (CARD16) DECLINE;
@@ -1987,7 +1987,7 @@ gdm_xdmcp_handle_manage (struct sockaddr_in *clnt_sa, gint len)
     }
 
     if G_UNLIKELY (gdm_get_value_bool (GDM_KEY_DEBUG)) {
-	    char *s = g_strndup (clnt_dspclass.data, clnt_dspclass.length);
+	    char *s = g_strndup ((char *) clnt_dspclass.data, clnt_dspclass.length);
 
 #ifdef ENABLE_IPV6
 	    if (clnt_sa->ss_family == AF_INET6)
@@ -2316,8 +2316,8 @@ gdm_xdmcp_send_failed (struct sockaddr_in *clnt_sa, CARD32 sessid)
     
     /* Don't translate, this goes over the wire to servers where we
      * don't know the charset or language, so it must be ascii */
-    status.data = "Failed to start session";
-    status.length = strlen (status.data);
+    status.data = (CARD8 *) "Failed to start session";
+    status.length = strlen ((char *) status.data);
     
     header.version = XDM_PROTOCOL_VERSION;
     header.opcode = (CARD16) FAILED;
@@ -2414,7 +2414,7 @@ gdm_xdmcp_send_alive (struct sockaddr_in *clnt_sa, CARD16 dspnum, CARD32 sessid)
     
     d = gdm_xdmcp_display_lookup (sessid);
     if (d == NULL)
-	    d = gdm_xdmcp_display_lookup_by_host(clnt_sa, dspnum);
+	    d = gdm_xdmcp_display_lookup_by_host (clnt_sa, dspnum);
 
     if (d != NULL) {
 	    send_sessid = d->sessionid;
@@ -2600,7 +2600,7 @@ gdm_xdmcp_display_alloc (
 	    d->name = g_strdup (":-1");
 	    d->dispnum = -1;
 
-	    d->server_uid = gdm_get_gdmuid();
+	    d->server_uid = gdm_get_gdmuid ();
 
 	    d->parent_auth_file = d->authfile;
 	    d->authfile = NULL;
@@ -2623,7 +2623,7 @@ gdm_xdmcp_display_lookup (CARD32 sessid)
     GSList *dlist = displays;
     GdmDisplay *d;
     
-    if(!sessid)
+    if (!sessid)
 	return (NULL);
 
     while (dlist) {
