@@ -23,6 +23,7 @@
 
 #include "config.h"
 
+#include <stdlib.h>
 #include <unistd.h>
 #include <locale.h>
 #include <string.h>
@@ -31,14 +32,10 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include <vicious.h>
-#include "viciousui.h"
-
 #include "gdm.h"
-
-#include "gdmwm.h"
 #include "gdmcommon.h"
 #include "gdmcomm.h"
+#include "gdmconfig.h"
 
 void
 gdm_common_abort (const gchar *format, ...)
@@ -70,41 +67,6 @@ gdm_common_setup_cursor (GdkCursorType type)
 	gdk_cursor_unref (cursor);
 }
 
-gboolean
-gdm_common_string_same (VeConfig *config, const char *cur, const char *key)
-{
-	char *val = ve_config_get_string (config, key);
-	if (strcmp (ve_sure_string (cur), ve_sure_string (val)) == 0) {
-		g_free (val);
-		return TRUE;
-	} else {
-		g_free (val);
-		return FALSE;
-	}
-}
-
-gboolean
-gdm_common_bool_same (VeConfig *config, gboolean cur, const char *key)
-{
-	gboolean val = ve_config_get_bool (config, key);
-	if (ve_bool_equal (cur, val)) {
-		return TRUE;
-	} else {
-		return FALSE;
-	}
-}
-
-gboolean
-gdm_common_int_same (VeConfig *config, int cur, const char *key)
-{
-	int val = ve_config_get_int (config, key);
-	if (cur == val) {
-		return TRUE;
-	} else {
-		return FALSE;
-	}
-}
-
 void
 gdm_common_login_sound (const gchar *GdmSoundProgram,
 			const gchar *GdmSoundOnLoginReadyFile,
@@ -309,13 +271,9 @@ gdm_common_get_config_file (void)
 }
 
 gboolean
-gdm_common_select_time_format (VeConfig *config)
+gdm_common_select_time_format (void)
 {
-	gchar *val;
-
-	g_return_val_if_fail (config != NULL, FALSE);
-
-	val = ve_config_get_string (config, GDM_KEY_USE_24_CLOCK);
+	gchar *val = gdm_config_get_string (GDM_KEY_USE_24_CLOCK);
 
 	if (val != NULL &&
 	    (val[0] == 'T' ||
@@ -323,24 +281,21 @@ gdm_common_select_time_format (VeConfig *config)
 	     val[0] == 'Y' ||
 	     val[0] == 'y' ||
 	     atoi (val) != 0)) {
-		g_free (val);
 		return TRUE;
 	} else if (val != NULL &&
 	    (val[0] == 'F' ||
 	     val[0] == 'f' ||
 	     val[0] == 'N' ||
 	     val[0] == 'n')) {
-		g_free (val);
 		return FALSE;
 	} else {
 		/* Value is "auto" (default), thus select according to
 		   "locale" settings. */
-		g_free(val);
 
 		/* Translators: Translate this to '12-hour', or
 		   '24-hour'. Meaning of the translation is the
 		   default time format in your locale. */
-		return strcmp("12-hour", _("24-hour")) != 0;
+		return strcmp ("12-hour", _("24-hour")) != 0;
 		/* Logic is that if translator does not understand the
 		   comment, then 24 hour format is selected. */
 	}
@@ -382,3 +337,42 @@ setup_background_color (gchar *bg_color)
     }
 }
 
+gchar *
+gdm_get_welcomemsg (void)
+{
+        gchar *welcomemsg;
+	gchar *tempstr;
+
+	/*
+	 * Translate the welcome msg in the client program since it is running as the
+	 * user and therefore has the appropriate language environment set.
+	 */
+        if (ve_string_empty (g_getenv ("GDM_IS_LOCAL"))) {
+                if (gdm_config_get_bool (GDM_KEY_DEFAULT_REMOTE_WELCOME))
+                        welcomemsg = g_strdup (_(GDM_DEFAULT_REMOTE_WELCOME_MSG));
+                else {
+			tempstr = gdm_config_get_translated_string (GDM_KEY_REMOTE_WELCOME);
+
+			if (tempstr == NULL ||
+			    strcmp (ve_sure_string (tempstr), GDM_DEFAULT_REMOTE_WELCOME_MSG) == 0)
+				welcomemsg = g_strdup (_(GDM_DEFAULT_REMOTE_WELCOME_MSG));
+			else
+				welcomemsg = g_strdup (tempstr);
+		}
+        } else {
+                if (gdm_config_get_bool (GDM_KEY_DEFAULT_WELCOME))
+                        welcomemsg = g_strdup (_(GDM_DEFAULT_WELCOME_MSG));
+                else {
+                        tempstr = gdm_config_get_translated_string (GDM_KEY_WELCOME);
+
+			if (tempstr == NULL ||
+			    strcmp (ve_sure_string (tempstr), GDM_DEFAULT_WELCOME_MSG) == 0)
+				welcomemsg = g_strdup (_(GDM_DEFAULT_WELCOME_MSG));
+			else
+				welcomemsg = g_strdup (tempstr);
+		}
+        }
+
+	return welcomemsg;
+}
+
