@@ -21,7 +21,7 @@
 #include <math.h>
 #include <string.h>
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <librsvg/rsvg.h>
 
 #include "gdm.h"
